==> sptk-3.5.7.05.tbz2: sptk-3.5.7.05/sptk3/CFTPConnect.h <==
/***************************************************************************
                          SIMPLY POWERFUL TOOLKIT (SPTK)
                          CFTPConnect.h  -  description
                             -------------------
    begin                : July 19 2003
    copyright            : (C) 2003 by Alexey Parshin. All rights reserved.
    email                : alexeyp@gmail.com
 ***************************************************************************/

/***************************************************************************
  Redistribution and use in source and binary forms, with or without 
  modification, are permitted provided that the following conditions are met:

  * Redistributions of source code must retain the above copyright notice, 
    this list of conditions and the following disclaimer.
  * Redistributions in binary form must reproduce the above copyright notice, 
    this list of conditions and the following disclaimer in the documentation 
    and/or other materials provided with the distribution.
  * Neither the name of the <ORGANIZATION> nor the names of its contributors 
    may be used to endorse or promote products derived from this software 
    without specific prior written permission.

  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER 
  OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
  EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
  PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
  PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
  LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
  NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
  SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 ***************************************************************************/
#ifndef __CFTPCONNECT_H__
#define __CFTPCONNECT_H__

#include <sptk3/CStrings.h>
#include <sptk3/CSocket.h>

namespace sptk {

/// @addtogroup utility Utility Classes
/// @{

/// @brief FTP socket
///
/// Connects to FTP server. It takes two of such sockets
/// to establish the correct FTP communication
class CFTPSocket : public CSocket {
    /// Server response string list
    CStrings  m_response;
public:
    /// Default constructor
    CFTPSocket();

    /// Destructor
    ~CFTPSocket();

    /// Establish the connection
    virtual void open(std::string hostName="", int port=0);

    /// Returns a reference to server response string list
    const CStrings& response() const {
        return m_response;
    }

    /// Logs in to the server
    const CStrings& login(std::string user,std::string password);

    /// Sends a command to the server
    const CStrings& command(std::string cmd);

    /// Reads server response after calling a command
    const CStrings& get_response();
};

/// Connection to the FTP server
class CFTPConnect {
protected:
    CFTPSocket        m_commandSocket;  ///< FTP command socket
    CFTPSocket        m_dataSocket;     ///< FTP data socket
    std::string       m_user;               ///< FTP user name
    std::string       m_password;           ///< FTP user password
    std::string       m_host;               ///< FTP host name
    int               m_port;           ///< FTP port
    bool              m_passive;        ///< Passive mode

protected:

    /// Opens data port on the FTP server
    void openDataPort();

    /// Sends command to the FTP server
    void command(std::string cmd);

    /// Gets the list from the FTP server
    void getList(std::string cmd,CStrings& list);

public:

    /// Constructor
    CFTPConnect();

    /// Destructor
    ~CFTPConnect();

    /// Sets the passive mode true/false
    void passive(bool p) {
        m_passive = p;
    }

    /// Returns the passive mode
    bool passive() const {
        return m_passive;
    }

    /// Sets the user name
    void user(std::string u) {
        m_user = u;
    }

    /// Returns the user name
    std::string user() const {
        return m_user;
    }

    /// Sets the user password
    void password(std::string p) {
        m_password = p;
    }

    /// Returns the user password
    std::string password() const {
        return m_password;
    }

    /// Sets the host name and port
    void host(std::string hostName,int portNumber=21);

    /// Opens the FTP connection
    void open();

    /// Closes the FTP connection
    void close();

    /// Returns the referense on the server response string list
    const CStrings& response() const {
        return m_commandSocket.response();
    }

    /// Returns true if the connection is active
    bool active() const {
        return m_commandSocket.active();
    }

    /// FTP quit command
    void cmd_quit();

    /// FTP type command
    void cmd_type(char type);

    /// FTP cd command
    void cmd_cd(std::string dir);

    /// FTP pwd command
    void cmd_pwd();

    /// FTP list command
    void cmd_list(CStrings& result);

    /// FTP nlist command
    void cmd_nlst(CStrings& result);

    /// FTP retr command
    void cmd_retr(std::string fileName);

    /// FTP store command
    void cmd_store(std::string fileName);
};
/// @}
}
#endif

==> sptk-3.5.7.14.tbz2: sptk-3.5.7.14/sptk3/CFTPConnect.h <==
/***************************************************************************
                          SIMPLY POWERFUL TOOLKIT (SPTK)
                          CFTPConnect.h  -  description
                             -------------------
    begin                : July 19 2003
    copyright            : (C) 2003 by Alexey Parshin. All rights reserved.
    email                : alexeyp@gmail.com
 ***************************************************************************/

/***************************************************************************
  Redistribution and use in source and binary forms, with or without 
  modification, are permitted provided that the following conditions are met:

  * Redistributions of source code must retain the above copyright notice, 
    this list of conditions and the following disclaimer.
  * Redistributions in binary form must reproduce the above copyright notice, 
    this list of conditions and the following disclaimer in the documentation 
    and/or other materials provided with the distribution.
  * Neither the name of the <ORGANIZATION> nor the names of its contributors 
    may be used to endorse or promote products derived from this software 
    without specific prior written permission.

  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER 
  OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
  EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
  PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
  PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
  LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
  NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
  SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 ***************************************************************************/
#ifndef __CFTPCONNECT_H__
#define __CFTPCONNECT_H__

#include <sptk3/CStrings.h>
#include <sptk3/CSocket.h>

namespace sptk {

/// @addtogroup utility Utility Classes
/// @{

/// @brief FTP socket
///
/// Connects to FTP server. It takes two of such sockets
/// to establish the correct FTP communication
class CFTPSocket : public CSocket {
    /// Server response string list
    CStrings  m_response;
public:
    /// Default constructor
    CFTPSocket();

    /// Destructor
    ~CFTPSocket();

    /// Establish the connection
	virtual void open(std::string hostName="", int port=0,CSocketOpenMode openMode=SOM_CONNECT);

    /// Returns a reference to server response string list
    const CStrings& response() const {
        return m_response;
    }

    /// Logs in to the server
    const CStrings& login(std::string user,std::string password);

    /// Sends a command to the server
    const CStrings& command(std::string cmd);

    /// Reads server response after calling a command
    const CStrings& get_response();
};

/// Connection to the FTP server
class CFTPConnect {
protected:
    CFTPSocket        m_commandSocket;  ///< FTP command socket
    CFTPSocket        m_dataSocket;     ///< FTP data socket
    std::string       m_user;               ///< FTP user name
    std::string       m_password;           ///< FTP user password
    std::string       m_host;               ///< FTP host name
    int               m_port;           ///< FTP port
    bool              m_passive;        ///< Passive mode

protected:

    /// Opens data port on the FTP server
    void openDataPort();

    /// Sends command to the FTP server
    void command(std::string cmd);

    /// Gets the list from the FTP server
    void getList(std::string cmd,CStrings& list);

public:

    /// Constructor
    CFTPConnect();

    /// Destructor
    ~CFTPConnect();

    /// Sets the passive mode true/false
    void passive(bool p) {
        m_passive = p;
    }

    /// Returns the passive mode
    bool passive() const {
        return m_passive;
    }

    /// Sets the user name
    void user(std::string u) {
        m_user = u;
    }

    /// Returns the user name
    std::string user() const {
        return m_user;
    }

    /// Sets the user password
    void password(std::string p) {
        m_password = p;
    }

    /// Returns the user password
    std::string password() const {
        return m_password;
    }

    /// Sets the host name and port
    void host(std::string hostName,int portNumber=21);

    /// Opens the FTP connection
    void open();

    /// Closes the FTP connection
    void close();

    /// Returns the referense on the server response string list
    const CStrings& response() const {
        return m_commandSocket.response();
    }

    /// Returns true if the connection is active
    bool active() const {
        return m_commandSocket.active();
    }

    /// FTP quit command
    void cmd_quit();

    /// FTP type command
    void cmd_type(char type);

    /// FTP cd command
    void cmd_cd(std::string dir);

    /// FTP pwd command
    void cmd_pwd();

    /// FTP list command
    void cmd_list(CStrings& result);

    /// FTP nlist command
    void cmd_nlst(CStrings& result);

    /// FTP retr command
    void cmd_retr(std::string fileName);

    /// FTP store command
    void cmd_store(std::string fileName);
};
/// @}
}
#endif
